@@ -10,12 +10,6 @@ class YollapayResponse:
     def json(self):
         return self._arguments
 
-    @property
-    def meta(self):
-        """Do not assume self.meta==200 means the transaction was approved
-        """
-        return self._arguments.get('meta', 204)
-
     @property
     def approved(self):
         """If the request was successful.
@@ -25,4 +19,7 @@ class YollapayResponse:
         return self._arguments.get('approved', False) is True
 
     def __nonzero__(self):
-        return self.approved
\ No newline at end of file
+        return self.approved
+
+    def __getitem__(self, index):
+        return self._arguments.get(index)
